# Universities exercise api
This is an exercise project to test pip packaging capability

###Installation

Run the following to install:

pip install universities-exercise-api-v1

###Usage
from universities_api import get_universities

Generate universities list:

universities= get_universities(url)
